@@ -3,14 +3,8 @@ import math
 
 import Box2D
 import numpy as np
-from Box2D.b2 import (
-    circleShape,
-    contactListener,
-    edgeShape,
-    fixtureDef,
-    polygonShape,
-    revoluteJointDef,
-)
+from Box2D.b2 import (circleShape, contactListener, edgeShape, fixtureDef, polygonShape,
+                      revoluteJointDef)
 from gym import spaces
 from gym.utils import seeding
 
@@ -50,6 +44,7 @@ WALKER_SEPERATION = 10  # in steps
 
 
 class ContactDetector(contactListener):
+
     def __init__(self, env):
         contactListener.__init__(self)
         self.env = env
@@ -89,14 +84,9 @@ class ContactDetector(contactListener):
 
 
 class BipedalWalker(Agent):
-    def __init__(
-        self,
-        world,
-        init_x=TERRAIN_STEP * TERRAIN_STARTPAD / 2,
-        init_y=TERRAIN_HEIGHT + 2 * LEG_H,
-        n_walkers=2,
-        seed=None,
-    ):
+
+    def __init__(self, world, init_x=TERRAIN_STEP * TERRAIN_STARTPAD / 2,
+                 init_y=TERRAIN_HEIGHT + 2 * LEG_H, n_walkers=2, seed=None):
         self.world = world
         self._n_walkers = n_walkers
         self.hull = None
@@ -127,19 +117,16 @@ class BipedalWalker(Agent):
             position=(init_x, init_y),
             fixtures=fixtureDef(
                 shape=polygonShape(
-                    vertices=[(x / SCALE, y / SCALE) for x, y in HULL_POLY]
-                ),
+                    vertices=[(x / SCALE, y / SCALE) for x, y in HULL_POLY]),
                 density=5.0,
                 friction=0.1,
                 groupIndex=self.walker_id,
-                restitution=0.0,
-            ),  # 0.99 bouncy
+                restitution=0.0)  # 0.99 bouncy
         )
         self.hull.color1 = (0.5, 0.4, 0.9)
         self.hull.color2 = (0.3, 0.3, 0.5)
-        self.hull.ApplyForceToCenter(
-            (self.np_random.uniform(-INITIAL_RANDOM, INITIAL_RANDOM), 0), True
-        )
+        self.hull.ApplyForceToCenter((self.np_random.uniform(-INITIAL_RANDOM, INITIAL_RANDOM), 0),
+                                     True)
 
         self.legs = []
         self.joints = []
@@ -152,10 +139,10 @@ class BipedalWalker(Agent):
                     density=1.0,
                     restitution=0.0,
                     groupIndex=self.walker_id,
-                ),  # collide with ground only
+                )  # collide with ground only
             )
-            leg.color1 = (0.6 - i / 10.0, 0.3 - i / 10.0, 0.5 - i / 10.0)
-            leg.color2 = (0.4 - i / 10.0, 0.2 - i / 10.0, 0.3 - i / 10.0)
+            leg.color1 = (0.6 - i / 10., 0.3 - i / 10., 0.5 - i / 10.)
+            leg.color2 = (0.4 - i / 10., 0.2 - i / 10., 0.3 - i / 10.)
             rjd = revoluteJointDef(
                 bodyA=self.hull,
                 bodyB=leg,
@@ -179,10 +166,10 @@ class BipedalWalker(Agent):
                     density=1.0,
                     restitution=0.0,
                     groupIndex=self.walker_id,
-                ),
+                )
             )
-            lower.color1 = (0.6 - i / 10.0, 0.3 - i / 10.0, 0.5 - i / 10.0)
-            lower.color2 = (0.4 - i / 10.0, 0.2 - i / 10.0, 0.3 - i / 10.0)
+            lower.color1 = (0.6 - i / 10., 0.3 - i / 10., 0.5 - i / 10.)
+            lower.color2 = (0.4 - i / 10., 0.2 - i / 10., 0.3 - i / 10.)
             rjd = revoluteJointDef(
                 bodyA=leg,
                 bodyB=lower,
@@ -202,6 +189,7 @@ class BipedalWalker(Agent):
         self.drawlist = self.legs + [self.hull]
 
         class LidarCallback(Box2D.b2.rayCastCallback):
+
             def ReportFixture(self, fixture, point, normal, fraction):
                 if (fixture.filterData.categoryBits & 1) == 0:
                     return -1
@@ -215,20 +203,16 @@ class BipedalWalker(Agent):
 
         self.joints[0].motorSpeed = float(SPEED_HIP * np.sign(action[0]))
         self.joints[0].maxMotorTorque = float(
-            MOTORS_TORQUE * np.clip(np.abs(action[0]), 0, 1)
-        )
+            MOTORS_TORQUE * np.clip(np.abs(action[0]), 0, 1))
         self.joints[1].motorSpeed = float(SPEED_KNEE * np.sign(action[1]))
         self.joints[1].maxMotorTorque = float(
-            MOTORS_TORQUE * np.clip(np.abs(action[1]), 0, 1)
-        )
+            MOTORS_TORQUE * np.clip(np.abs(action[1]), 0, 1))
         self.joints[2].motorSpeed = float(SPEED_HIP * np.sign(action[2]))
         self.joints[2].maxMotorTorque = float(
-            MOTORS_TORQUE * np.clip(np.abs(action[2]), 0, 1)
-        )
+            MOTORS_TORQUE * np.clip(np.abs(action[2]), 0, 1))
         self.joints[3].motorSpeed = float(SPEED_KNEE * np.sign(action[3]))
         self.joints[3].maxMotorTorque = float(
-            MOTORS_TORQUE * np.clip(np.abs(action[3]), 0, 1)
-        )
+            MOTORS_TORQUE * np.clip(np.abs(action[3]), 0, 1))
 
     def get_observation(self):
         pos = self.hull.position
@@ -237,11 +221,10 @@ class BipedalWalker(Agent):
         for i in range(10):
             self.lidar[i].fraction = 1.0
             self.lidar[i].p1 = pos
-            self.lidar[i].p2 = (
-                pos[0] + math.sin(1.5 * i / 10.0) * LIDAR_RANGE,
-                pos[1] - math.cos(1.5 * i / 10.0) * LIDAR_RANGE,
-            )
-            self.world.RayCast(self.lidar[i], self.lidar[i].p1, self.lidar[i].p2)
+            self.lidar[i].p2 = (pos[0] + math.sin(1.5 * i / 10.0) * LIDAR_RANGE,
+                                pos[1] - math.cos(1.5 * i / 10.0) * LIDAR_RANGE)
+            self.world.RayCast(
+                self.lidar[i], self.lidar[i].p1, self.lidar[i].p2)
 
         state = [
             # Normal angles up to 0.5 here, but sure more is possible.
@@ -260,7 +243,7 @@ class BipedalWalker(Agent):
             self.joints[2].speed / SPEED_HIP,
             self.joints[3].angle + 1.0,
             self.joints[3].speed / SPEED_KNEE,
-            1.0 if self.legs[3].ground_contact else 0.0,
+            1.0 if self.legs[3].ground_contact else 0.0
         ]
 
         state += [l.fraction for l in self.lidar]
@@ -271,49 +254,32 @@ class BipedalWalker(Agent):
     @property
     def observation_space(self):
         # 24 original obs (joints, etc), 2 displacement obs for each neighboring walker, 3 for package
-        return spaces.Box(
-            low=np.float32(-np.inf),
-            high=np.float32(np.inf),
-            shape=(24 + 4 + 3,),
-            dtype=np.float32,
-        )
+        return spaces.Box(low=np.float32(-np.inf), high=np.float32(np.inf), shape=(24 + 4 + 3,), dtype=np.float32)
 
     @property
     def action_space(self):
-        return spaces.Box(
-            low=np.float32(-1), high=np.float32(1), shape=(4,), dtype=np.float32
-        )
+        return spaces.Box(low=np.float32(-1), high=np.float32(1), shape=(4,), dtype=np.float32)
 
 
-class MultiWalkerEnv:
+class MultiWalkerEnv():
 
-    metadata = {"render.modes": ["human", "rgb_array"], "video.frames_per_second": FPS}
+    metadata = {'render.modes': [
+        'human', 'rgb_array'], 'video.frames_per_second': FPS}
 
     hardcore = False
 
-    def __init__(
-        self,
-        n_walkers=3,
-        position_noise=1e-3,
-        angle_noise=1e-3,
-        local_ratio=1.0,
-        forward_reward=1.0,
-        terminate_reward=-100.0,
-        fall_reward=-10.0,
-        terminate_on_fall=True,
-        remove_on_fall=True,
-        max_cycles=500,
-    ):
+    def __init__(self, n_walkers=3, position_noise=1e-3, angle_noise=1e-3, local_ratio=1.0,
+                 forward_reward=1.0, terminate_reward=-100.0, fall_reward=-10.0, terminate_on_fall=True, remove_on_fall=True, max_cycles=500):
         """
-        n_walkers: number of bipedal walkers in environment
-        position_noise: noise applied to agent positional sensor observations
-        angle_noise: noise applied to agent rotational sensor observations
-        local_ratio: proportion of reward allocated locally vs distributed among all agents
-        forward_reward: reward applied for an agent standing, scaled by agent's x coordinate
-        fall_reward: reward applied when an agent falls down
-        terminate_reward: reward applied for each fallen walker in environment
-        terminate_on_fall: toggles whether agent is done if it falls down
-        max_cycles: after max_cycles steps all agents will return done
+            n_walkers: number of bipedal walkers in environment
+            position_noise: noise applied to agent positional sensor observations
+            angle_noise: noise applied to agent rotational sensor observations
+            local_ratio: proportion of reward allocated locally vs distributed among all agents
+            forward_reward: reward applied for an agent standing, scaled by agent's x coordinate
+            fall_reward: reward applied when an agent falls down
+            terminate_reward: reward applied for each fallen walker in environment
+            terminate_on_fall: toggles whether agent is done if it falls down
+            max_cycles: after max_cycles steps all agents will return done
         """
 
         self.n_walkers = n_walkers
@@ -350,11 +316,13 @@ class MultiWalkerEnv:
             init_x + WALKER_SEPERATION * i * TERRAIN_STEP for i in range(self.n_walkers)
         ]
         self.walkers = [
-            BipedalWalker(self.world, init_x=sx, init_y=init_y, seed=self.seed_val)
+            BipedalWalker(self.world, init_x=sx,
+                          init_y=init_y, seed=self.seed_val)
             for sx in self.start_x
         ]
         self.num_agents = len(self.walkers)
-        self.observation_space = [agent.observation_space for agent in self.walkers]
+        self.observation_space = [
+            agent.observation_space for agent in self.walkers]
         self.action_space = [agent.action_space for agent in self.walkers]
 
         self.package_scale = self.n_walkers / 1.75
@@ -365,7 +333,7 @@ class MultiWalkerEnv:
         self.prev_shaping = np.zeros(self.n_walkers)
         self.prev_package_shaping = 0.0
 
-        self.terrain_length = int(TERRAIN_LENGTH * self.n_walkers * 1 / 8.0)
+        self.terrain_length = int(TERRAIN_LENGTH * self.n_walkers * 1 / 8.)
 
     @property
     def agents(self):
@@ -457,9 +425,7 @@ class MultiWalkerEnv:
             yd = (self.package.position.y - y) / self.package_length
             neighbor_obs.append(self.np_random.normal(xd, self.position_noise))
             neighbor_obs.append(self.np_random.normal(yd, self.position_noise))
-            neighbor_obs.append(
-                self.np_random.normal(self.package.angle, self.angle_noise)
-            )
+            neighbor_obs.append(self.np_random.normal(self.package.angle, self.angle_noise))
             obs.append(np.array(walker_obs + neighbor_obs))
 
             # shaping = 130 * pos[0] / SCALE
@@ -469,14 +435,11 @@ class MultiWalkerEnv:
             self.prev_shaping[i] = shaping
 
         package_shaping = self.forward_reward * 130 * self.package.position.x / SCALE
-        rewards += package_shaping - self.prev_package_shaping
+        rewards += (package_shaping - self.prev_package_shaping)
         self.prev_package_shaping = package_shaping
 
-        self.scroll = (
-            xpos.mean()
-            - VIEWPORT_W / SCALE / 5
-            - (self.n_walkers - 1) * WALKER_SEPERATION * TERRAIN_STEP
-        )
+        self.scroll = xpos.mean() - VIEWPORT_W / SCALE / 5 - (self.n_walkers - 1) * \
+            WALKER_SEPERATION * TERRAIN_STEP
 
         done = [False] * self.n_walkers
         if self.game_over or pos[0] < 0:
@@ -509,38 +472,25 @@ class MultiWalkerEnv:
             self.last_obs = mod_obs
             global_reward = rewards.mean()
             local_reward = rewards * self.local_ratio
-            self.last_rewards = (
-                global_reward * (1.0 - self.local_ratio)
-                + local_reward * self.local_ratio
-            )
+            self.last_rewards = global_reward * (1. - self.local_ratio) + local_reward * self.local_ratio
             self.last_dones = done
             self.frames = self.frames + 1
 
     def get_last_rewards(self):
-        return dict(
-            zip(
-                list(range(self.n_walkers)),
-                map(lambda r: np.float64(r), self.last_rewards),
-            )
-        )
+        return dict(zip(list(range(self.n_walkers)), map(lambda r: np.float64(r), self.last_rewards)))
 
     def get_last_dones(self):
         return dict(zip(self.agent_list, self.last_dones))
 
     def get_last_obs(self):
-        return dict(
-            zip(
-                list(range(self.n_walkers)),
-                [walker.get_observation() for walker in self.walkers],
-            )
-        )
+        return dict(zip(list(range(self.n_walkers)), [walker.get_observation() for walker in self.walkers]))
 
     def observe(self, agent):
         o = self.last_obs[agent]
         o = np.array(o, dtype=np.float32)
         return o
 
-    def render(self, mode="human", close=False):
+    def render(self, mode='human', close=False):
         if close:
             if self.viewer is not None:
                 self.viewer.close()
@@ -550,41 +500,26 @@ class MultiWalkerEnv:
         render_scale = 0.75
 
         from gym.envs.classic_control import rendering
-
         if self.viewer is None:
             self.viewer = rendering.Viewer(VIEWPORT_W, VIEWPORT_H)
-        self.viewer.set_bounds(
-            self.scroll,
-            VIEWPORT_W / SCALE * self.package_scale * render_scale + self.scroll,
-            0,
-            VIEWPORT_H / SCALE * self.package_scale * render_scale,
-        )
+        self.viewer.set_bounds(self.scroll,
+                               VIEWPORT_W / SCALE * self.package_scale * render_scale + self.scroll,
+                               0, VIEWPORT_H / SCALE * self.package_scale * render_scale)
 
-        self.viewer.draw_polygon(
-            [
-                (self.scroll, 0),
-                (
-                    self.scroll
-                    + VIEWPORT_W * self.package_scale / SCALE * render_scale,
-                    0,
-                ),
-                (
-                    self.scroll
-                    + VIEWPORT_W * self.package_scale / SCALE * render_scale,
-                    VIEWPORT_H / SCALE * self.package_scale * render_scale,
-                ),
-                (self.scroll, VIEWPORT_H / SCALE * self.package_scale * render_scale),
-            ],
-            color=(0.9, 0.9, 1.0),
-        )
+        self.viewer.draw_polygon([
+            (self.scroll, 0),
+            (self.scroll + VIEWPORT_W * self.package_scale / SCALE * render_scale, 0),
+            (self.scroll + VIEWPORT_W * self.package_scale / SCALE * render_scale,
+             VIEWPORT_H / SCALE * self.package_scale * render_scale),
+            (self.scroll, VIEWPORT_H / SCALE * self.package_scale * render_scale),
+        ], color=(0.9, 0.9, 1.0))
         for poly, x1, x2 in self.cloud_poly:
             if x2 < self.scroll / 2:
                 continue
             if x1 > self.scroll / 2 + VIEWPORT_W / SCALE * self.package_scale:
                 continue
             self.viewer.draw_polygon(
-                [(p[0] + self.scroll / 2, p[1]) for p in poly], color=(1, 1, 1)
-            )
+                [(p[0] + self.scroll / 2, p[1]) for p in poly], color=(1, 1, 1))
         for poly, color in self.terrain_poly:
             if poly[1][0] < self.scroll:
                 continue
@@ -596,12 +531,9 @@ class MultiWalkerEnv:
         i = self.lidar_render
         for walker in self.walkers:
             if i < 2 * len(walker.lidar):
-                l = (
-                    walker.lidar[i]
-                    if i < len(walker.lidar)
-                    else walker.lidar[len(walker.lidar) - i - 1]
-                )
-                self.viewer.draw_polyline([l.p1, l.p2], color=(1, 0, 0), linewidth=1)
+                l = walker.lidar[i] if i < len(walker.lidar) else walker.lidar[len(walker.lidar) - i - 1]
+                self.viewer.draw_polyline(
+                    [l.p1, l.p2], color=(1, 0, 0), linewidth=1)
 
         for obj in self.drawlist:
             for f in obj.fixtures:
@@ -609,32 +541,27 @@ class MultiWalkerEnv:
                 if type(f.shape) is circleShape:
                     t = rendering.Transform(translation=trans * f.shape.pos)
                     self.viewer.draw_circle(
-                        f.shape.radius, 30, color=obj.color1
-                    ).add_attr(t)
-                    self.viewer.draw_circle(
-                        f.shape.radius, 30, color=obj.color2, filled=False, linewidth=2
-                    ).add_attr(t)
+                        f.shape.radius, 30, color=obj.color1).add_attr(t)
+                    self.viewer.draw_circle(f.shape.radius, 30, color=obj.color2, filled=False,
+                                            linewidth=2).add_attr(t)
                 else:
                     path = [trans * v for v in f.shape.vertices]
                     self.viewer.draw_polygon(path, color=obj.color1)
                     path.append(path[0])
-                    self.viewer.draw_polyline(path, color=obj.color2, linewidth=2)
+                    self.viewer.draw_polyline(
+                        path, color=obj.color2, linewidth=2)
 
         flagy1 = TERRAIN_HEIGHT
         flagy2 = flagy1 + 50 / SCALE
         x = TERRAIN_STEP * 3
         self.viewer.draw_polyline(
-            [(x, flagy1), (x, flagy2)], color=(0, 0, 0), linewidth=2
-        )
-        f = [
-            (x, flagy2),
-            (x, flagy2 - 10 / SCALE),
-            (x + 25 / SCALE, flagy2 - 5 / SCALE),
-        ]
+            [(x, flagy1), (x, flagy2)], color=(0, 0, 0), linewidth=2)
+        f = [(x, flagy2), (x, flagy2 - 10 / SCALE),
+             (x + 25 / SCALE, flagy2 - 5 / SCALE)]
         self.viewer.draw_polygon(f, color=(0.9, 0.2, 0))
         self.viewer.draw_polyline(f + [f[0]], color=(0, 0, 0), linewidth=2)
 
-        return self.viewer.render(return_rgb_array=mode == "rgb_array")
+        return self.viewer.render(return_rgb_array=mode == 'rgb_array')
 
     def _generate_package(self):
         init_x = np.mean(self.start_x)
@@ -642,18 +569,13 @@ class MultiWalkerEnv:
         self.package = self.world.CreateDynamicBody(
             position=(init_x, init_y),
             fixtures=fixtureDef(
-                shape=polygonShape(
-                    vertices=[
-                        (x * self.package_scale / SCALE, y / SCALE)
-                        for x, y in PACKAGE_POLY
-                    ]
-                ),
+                shape=polygonShape(vertices=[(x * self.package_scale / SCALE, y / SCALE)
+                                             for x, y in PACKAGE_POLY]),
                 density=1.0,
                 friction=0.5,
                 categoryBits=0x004,
                 # maskBits=0x001,  # collide only with ground
-                restitution=0.0,
-            ),  # 0.99 bouncy
+                restitution=0.0)  # 0.99 bouncy
         )
         self.package.color1 = (0.5, 0.4, 0.9)
         self.package.color2 = (0.3, 0.3, 0.5)
@@ -686,23 +608,13 @@ class MultiWalkerEnv:
                     (x + TERRAIN_STEP, y - 4 * TERRAIN_STEP),
                     (x, y - 4 * TERRAIN_STEP),
                 ]
-                t = self.world.CreateStaticBody(
-                    fixtures=fixtureDef(
-                        shape=polygonShape(vertices=poly), friction=FRICTION
-                    )
-                )
+                t = self.world.CreateStaticBody(fixtures=fixtureDef(
+                    shape=polygonShape(vertices=poly), friction=FRICTION))
                 t.color1, t.color2 = (1, 1, 1), (0.6, 0.6, 0.6)
                 self.terrain.append(t)
-                t = self.world.CreateStaticBody(
-                    fixtures=fixtureDef(
-                        shape=polygonShape(
-                            vertices=[
-                                (p[0] + TERRAIN_STEP * counter, p[1]) for p in poly
-                            ]
-                        ),
-                        friction=FRICTION,
-                    )
-                )
+                t = self.world.CreateStaticBody(fixtures=fixtureDef(shape=polygonShape(
+                    vertices=[(p[0] + TERRAIN_STEP * counter, p[1]) for p in poly]),
+                    friction=FRICTION))
                 t.color1, t.color2 = (1, 1, 1), (0.6, 0.6, 0.6)
                 self.terrain.append(t)
                 counter += 2
@@ -721,11 +633,8 @@ class MultiWalkerEnv:
                     (x + counter * TERRAIN_STEP, y + counter * TERRAIN_STEP),
                     (x, y + counter * TERRAIN_STEP),
                 ]
-                t = self.world.CreateStaticBody(
-                    fixtures=fixtureDef(
-                        shape=polygonShape(vertices=poly), friction=FRICTION
-                    )
-                )
+                t = self.world.CreateStaticBody(fixtures=fixtureDef(
+                    shape=polygonShape(vertices=poly), friction=FRICTION))
                 t.color1, t.color2 = (1, 1, 1), (0.6, 0.6, 0.6)
                 self.terrain.append(t)
 
@@ -736,28 +645,17 @@ class MultiWalkerEnv:
                 original_y = y
                 for s in range(stair_steps):
                     poly = [
-                        (
-                            x + (s * stair_width) * TERRAIN_STEP,
-                            y + (s * stair_height) * TERRAIN_STEP,
-                        ),
-                        (
-                            x + ((1 + s) * stair_width) * TERRAIN_STEP,
-                            y + (s * stair_height) * TERRAIN_STEP,
-                        ),
-                        (
-                            x + ((1 + s) * stair_width) * TERRAIN_STEP,
-                            y + (-1 + s * stair_height) * TERRAIN_STEP,
-                        ),
-                        (
-                            x + (s * stair_width) * TERRAIN_STEP,
-                            y + (-1 + s * stair_height) * TERRAIN_STEP,
-                        ),
+                        (x + (s * stair_width) * TERRAIN_STEP,
+                         y + (s * stair_height) * TERRAIN_STEP),
+                        (x + ((1 + s) * stair_width) * TERRAIN_STEP,
+                         y + (s * stair_height) * TERRAIN_STEP),
+                        (x + ((1 + s) * stair_width) * TERRAIN_STEP,
+                         y + (-1 + s * stair_height) * TERRAIN_STEP),
+                        (x + (s * stair_width) * TERRAIN_STEP,
+                         y + (-1 + s * stair_height) * TERRAIN_STEP),
                     ]
-                    t = self.world.CreateStaticBody(
-                        fixtures=fixtureDef(
-                            shape=polygonShape(vertices=poly), friction=FRICTION
-                        )
-                    )
+                    t = self.world.CreateStaticBody(fixtures=fixtureDef(
+                        shape=polygonShape(vertices=poly), friction=FRICTION))
                     t.color1, t.color2 = (1, 1, 1), (0.6, 0.6, 0.6)
                     self.terrain.append(t)
                 counter = stair_steps * stair_width
@@ -771,7 +669,8 @@ class MultiWalkerEnv:
             self.terrain_y.append(y)
             counter -= 1
             if counter == 0:
-                counter = self.np_random.randint(TERRAIN_GRASS / 2, TERRAIN_GRASS)
+                counter = self.np_random.randint(
+                    TERRAIN_GRASS / 2, TERRAIN_GRASS)
                 if state == GRASS and hardcore:
                     state = self.np_random.randint(1, _STATES_)
                     oneshot = True
@@ -781,13 +680,12 @@ class MultiWalkerEnv:
 
         self.terrain_poly = []
         for i in range(self.terrain_length - 1):
-            poly = [
-                (self.terrain_x[i], self.terrain_y[i]),
-                (self.terrain_x[i + 1], self.terrain_y[i + 1]),
-            ]
-            t = self.world.CreateStaticBody(
-                fixtures=fixtureDef(shape=edgeShape(vertices=poly), friction=FRICTION)
-            )
+            poly = [(self.terrain_x[i], self.terrain_y[i]),
+                    (self.terrain_x[i + 1], self.terrain_y[i + 1])]
+            t = self.world.CreateStaticBody(fixtures=fixtureDef(
+                shape=edgeShape(vertices=poly),
+                friction=FRICTION
+            ))
             color = (0.3, 1.0 if i % 2 == 0 else 0.8, 0.3)
             t.color1 = color
             t.color2 = color
@@ -803,17 +701,8 @@ class MultiWalkerEnv:
         for i in range(self.terrain_length // 20):
             x = self.np_random.uniform(0, self.terrain_length) * TERRAIN_STEP
             y = VIEWPORT_H / SCALE * 3 / 4
-            poly = [
-                (
-                    x
-                    + 15 * TERRAIN_STEP * math.sin(3.14 * 2 * a / 5)
-                    + self.np_random.uniform(0, 5 * TERRAIN_STEP),
-                    y
-                    + 5 * TERRAIN_STEP * math.cos(3.14 * 2 * a / 5)
-                    + self.np_random.uniform(0, 5 * TERRAIN_STEP),
-                )
-                for a in range(5)
-            ]
+            poly = [(x + 15 * TERRAIN_STEP * math.sin(3.14 * 2 * a / 5) + self.np_random.uniform(
+                0, 5 * TERRAIN_STEP), y + 5 * TERRAIN_STEP * math.cos(3.14 * 2 * a / 5) + self.np_random.uniform(0, 5 * TERRAIN_STEP)) for a in range(5)]
             x1 = min(p[0] for p in poly)
             x2 = max(p[0] for p in poly)
             self.cloud_poly.append((poly, x1, x2))
