@@ -2,13 +2,5 @@ from .agent_layer import AgentLayer
 from .agent_utils import create_agents, feasible_position_exp, set_agents
 from .controllers import RandomPolicy, SingleActionPolicy
 from .discrete_agent import DiscreteAgent
-from .two_d_maps import (
-    add_rectangle,
-    complex_map,
-    cross_map,
-    gen_map,
-    multi_scale_map,
-    rectangle_map,
-    resize,
-    simple_soccer_map,
-)
+from .two_d_maps import (add_rectangle, complex_map, cross_map, gen_map, multi_scale_map,
+                         rectangle_map, resize, simple_soccer_map)
