@@ -19,7 +19,7 @@ parallel_env = parallel_wrapper_fn(env)
 
 class raw_env(AECEnv):
 
-    metadata = {"render.modes": ["human", "rgb_array"], "name": "waterworld_v3"}
+    metadata = {'render.modes': ['human', "rgb_array"], 'name': 'waterworld_v3'}
 
     def __init__(self, *args, **kwargs):
         super().__init__()
@@ -31,9 +31,16 @@ class raw_env(AECEnv):
         self._agent_selector = agent_selector(self.agents)
         # spaces
         self.action_spaces = dict(zip(self.agents, self.env.action_space))
-        self.observation_spaces = dict(zip(self.agents, self.env.observation_space))
+        self.observation_spaces = dict(
+            zip(self.agents, self.env.observation_space))
         self.has_reset = False
 
+    def observation_space(self, agent):
+        return self.observation_spaces[agent]
+
+    def action_space(self, agent):
+        return self.action_spaces[agent]
+
     def seed(self, seed=None):
         self.env.seed(seed)
 
