@@ -6,12 +6,6 @@ from ..env import ParallelEnv
 class BaseParallelWraper(ParallelEnv):
     def __init__(self, env):
         self.env = env
-        # try to access these parameters for backwards compatability
-        try:
-            self._observation_spaces = self.env.observation_spaces
-            self._action_spaces = self.env.action_spaces
-        except AttributeError:
-            pass
 
         self.metadata = env.metadata
         try:
@@ -19,6 +13,12 @@ class BaseParallelWraper(ParallelEnv):
         except AttributeError:
             pass
 
+        # Not every environment has the .state_space attribute implemented
+        try:
+            self.state_space = self.env.state_space
+        except AttributeError:
+            pass
+
     def reset(self):
         res = self.env.reset()
         self.agents = self.env.agents
@@ -48,7 +48,7 @@ class BaseParallelWraper(ParallelEnv):
             "The `observation_spaces` dictionary is deprecated. Use the `observation_space` function instead."
         )
         try:
-            return self._observation_spaces
+            return {agent: self.observation_space(agent) for agent in self.possible_agents}
         except AttributeError:
             raise AttributeError(
                 "The base environment does not have an `observation_spaces` dict attribute. Use the environments `observation_space` method instead"
@@ -60,7 +60,7 @@ class BaseParallelWraper(ParallelEnv):
             "The `action_spaces` dictionary is deprecated. Use the `action_space` function instead."
         )
         try:
-            return self._action_spaces
+            return {agent: self.action_space(agent) for agent in self.possible_agents}
         except AttributeError:
             raise AttributeError(
                 "The base environment does not have an action_spaces dict attribute. Use the environments `action_space` method instead"
