@@ -11,10 +11,10 @@ class ClipOutOfBoundsWrapper(BaseWrapper):
     '''
     def __init__(self, env):
         super().__init__(env)
-        assert all(isinstance(space, Box) for space in self.action_spaces.values()), "should only use ClipOutOfBoundsWrapper for Box spaces"
+        assert all(isinstance(self.action_space(agent), Box) for agent in getattr(self, 'possible_agents', [])), "should only use ClipOutOfBoundsWrapper for Box spaces"
 
     def step(self, action):
-        space = self.action_spaces[self.agent_selection]
+        space = self.action_space(self.agent_selection)
         if not (action is None and self.dones[self.agent_selection]) and not space.contains(action):
             assert space.shape == action.shape, f"action should have shape {space.shape}, has shape {action.shape}"
             if np.isnan(action).any():
